@@ -17,7 +17,7 @@
 namespace gdestraier {
   namespace model {
 
-    preferences::preferences()
+    preferences::preferences(char const* path)
     {
       GUI_.mainwindow_.top_ = -1;
       GUI_.mainwindow_.left_ = -1;
@@ -27,9 +27,12 @@ namespace gdestraier {
       path_ = PKGDATADIR "/gdestraierrc";
       load();
 
-
-      path_ = getenv("HOME");
-      path_ += "/.gdestraierrc";
+      if (path != 0)
+        path_ = path;
+      else {
+        path_ = getenv("HOME");
+        path_ += "/.gdestraierrc";
+      }
     }
 
 
